API documentation
=================

.. automodule:: picuplib

Picuplib basicly provides to different interfaces a function based and a class
based. The class based just wrapps the function based but stores the apikey and
default settings for the resize, rotation and noexif attribiutes.

.. autofunction:: upload

.. autofunction:: remote_upload


:class:`Upload`

.. autoclass:: Upload

.. automethod:: Upload.upload

.. automethod:: Upload.remote_upload


